@@ -2,6 +2,7 @@ from pythautomata.base_types.sequence import Sequence
 from pythautomata.automata.wheighted_automaton_definition.weighted_automaton import WeightedAutomaton
 from pythautomata.abstract.probabilistic_model import ProbabilisticModel
 from pythautomata.utilities.sequence_generator import SequenceGenerator
+from pythautomata.utilities.uniform_length_sequence_generator import UniformLengthSequenceGenerator
 from pymodelextractor.teachers.probabilistic_teacher import ProbabilisticTeacher
 from pythautomata.abstract.finite_automaton import FiniteAutomataComparator
 from math import ceil, log, comb
@@ -23,7 +24,7 @@ class PACProbabilisticTeacher(ProbabilisticTeacher):
         self.epsilon_star = 0
         self._compute_epsilon_star = compute_epsilon_star
         if sequence_generator is None:
-            self._sequence_generator = SequenceGenerator(self._target_model.alphabet, max_seq_length= max_seq_length)
+            self._sequence_generator = UniformLengthSequenceGenerator(self._target_model.alphabet, max_seq_length= max_seq_length)
         else:
             self._sequence_generator = sequence_generator
 
